@@ -111,11 +111,11 @@ class encrypt(color_print):
         else:
             if SecHashAlg in ("lm","nt"):
                 self.printERROR(_("ERROR") + " getHashPasswd: " +
-                            (_("Failed to support '%s' crypto algorithm")
+                            (_("Failed to support '%s' encryption algorithm")
                             %SecHashAlg) + " " +  _("without py-smbpasswd"))
             else:
                 self.printERROR(_("ERROR") + " getHashPasswd: " +
-                            _("Failed to support '%s' crypto algorithm")
+                            _("Failed to support '%s' encryption algorithm")
                             %SecHashAlg)
             return False
         return hashPwd
@@ -597,6 +597,6 @@ def getHash(password, encr):
     if hashPwd:
         return hashPwd
     else:
-        encryptObj.printERROR(_("Error encrypt password, "
+        encryptObj.printERROR(_("Password encryption error, "
                                     "method getHash()"))
         cl_overriding.exit(1)
