@@ -732,9 +732,11 @@ class FStab(object):
 
     def rebuildCache(self):
         """Rebuild cache from fstab file"""
+        def setlen(ar):
+            return ar[:6]+[""]*(6-len(ar))
         self.cache = \
-            map(lambda x:map(lambda y:y.strip(),x.split()),
-            filter(lambda x:x and not x.lstrip().startswith("#"),
+            map(lambda x:setlen(map(lambda y:y.strip(),x.split())),
+            filter(lambda x:x.strip() and not x.lstrip().startswith("#"),
             open(self.fstab_file,'r').read().split('\n')))
         for data in self.cache:
             convertDev = lambda x: path.realpath(x) if x.startswith('/') else x
