@@ -197,10 +197,8 @@ class VariableClAutoupdateSet(Variable):
 
     def get(self):
         if self.Get('cl_dispatch_conf') == 'usenew':
-            print "ON"
             return "on"
         else:
-            print "OFF"
             return "off"
 
 class VariableClDispatchConf(Variable):
